@@ -8,7 +8,7 @@
         0)
     call <- call[c(1, m)]
     call[[1]] <- as.name("ordiParseFormula")
-    out <- eval(call, parent.frame())[c("Z", "Y")]
+    out <- eval(call, environment(), parent.frame())[c("Z", "Y")]
     m <- list()
     if (!is.null(out$Z))
         m$Conditions <- out$Z
