@@ -3,14 +3,26 @@
 {
     X <- scores(X, display = scores, ...)
     Y <- scores(Y, display = scores, ...)
-    sol <- procrustes(X, Y, symmetric = TRUE)
+    ## Centre and normalize X & Y here so that the permutations will
+    ## be faster
+    X <- scale(X, scale = FALSE)
+    Y <- scale(Y, scale = FALSE)
+    X <- X/sqrt(sum(X^2))
+    Y <- Y/sqrt(sum(Y^2))
+    ## Transformed X and Y will yield symmetric procrustes() and we
+    ## need not specify that in the call (but we set it symmetric
+    ## after the call).
+    sol <- procrustes(X, Y, symmetric = FALSE)
+    sol$symmetric <- TRUE
     sol$t0 <- sqrt(1 - sol$ss)
     N <- nrow(X)
     perm <- rep(0, permutations)
     for (i in 1:permutations) {
         take <- permuted.index(N, strata)
-        tmp <- procrustes(X, Y[take, ], symmetric = TRUE)$ss
-        perm[i] <- sqrt(1 - tmp)
+        ## avoid overhead of procrustes() and only evaluate the
+        ## statistic by svd (hand crafted from r2388 of the devel
+        ## branch).
+        perm[i] <- sum(svd(crossprod(X, Y[take,]), nv = 0, nu = 0)$d)
     }
     Pval <- (sum(perm >= sol$t0) + 1)/(permutations + 1)
     if (!missing(strata)) {
