@@ -1,6 +1,6 @@
 `text.cca` <-
     function (x, display = "sites", labels, choices = c(1, 2), scaling = 2,
-              arrow.mul, head.arrow = 0.05, select, const, ...)
+              arrow.mul, head.arrow = 0.05, select, const, axis.bp = TRUE, ...)
 {
     formals(arrows) <- c(formals(arrows), alist(... = ))
     if (length(display) > 1)
@@ -29,11 +29,13 @@
         pts <- pts * arrow.mul
         arrows(0, 0, pts[, 1], pts[, 2], length = head.arrow,
                ...)
-        pts <- pts * 1.1
-        axis(3, at = c(-arrow.mul, 0, arrow.mul), labels = rep("",
-                                                  3))
-        axis(4, at = c(-arrow.mul, 0, arrow.mul), labels = c(-1,
-                                                  0, 1))
+        pts <- ordiArrowTextXY(pts, rownames(pts), ...)
+        if (axis.bp) {
+            axis(side = 3, at = c(-arrow.mul, 0, arrow.mul),
+                 labels = rep("", 3))
+            axis(side = 4, at = c(-arrow.mul, 0, arrow.mul),
+                 labels = c(-1, 0, 1))
+        }
     }
     text(pts, labels = rownames(pts), ...)
     invisible()
